from google.protobuf.json_format import ParseDict
from dig_ass_ep_protos.DigitalAssistantEntryPoint_pb2_grpc import DigitalAssistantEntryPointStub
from dig_ass_ep_protos.DigitalAssistantEntryPoint_pb2 import DigitalAssistantEntryPointRequest, DigitalAssistantEntryPointResponse, OuterContextItem

from .abstract_client import AbstractClient

class EntryPointClient(AbstractClient):
    def __init__(self, address) -> None:
        super().__init__(address)
        self._stub = DigitalAssistantEntryPointStub(self._channel)

    def __call__(self, text: str, outer_context: dict, image: bytearray, pdf: bytearray):
        request = DigitalAssistantEntryPointRequest(
            Text=text,
            OuterContext=ParseDict(outer_context, OuterContextItem()),
            image=image,
            pdf=pdf
        )
        response: DigitalAssistantEntryPointResponse = self._stub.GetTextResponse(request)
        return response.Text



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dig_ass_ep_protos/DigitalAssistantEntryPoint.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dig_ass_ep_protos/DigitalAssistantEntryPoint.proto\x12\rdig.ass.ep.v1\"2\n\"DigitalAssistantEntryPointResponse\x12\x0c\n\x04Text\x18\x01 \x01(\t\"\x84\x01\n!DigitalAssistantEntryPointRequest\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x35\n\x0cOuterContext\x18\x02 \x01(\x0b\x32\x1f.dig.ass.ep.v1.OuterContextItem\x12\r\n\x05Image\x18\x03 \x01(\x0c\x12\x0b\n\x03PDF\x18\x04 \x01(\x0c\"O\n\x10OuterContextItem\x12\x0b\n\x03Sex\x18\x01 \x01(\x08\x12\x0b\n\x03\x41ge\x18\x02 \x01(\r\x12\x0e\n\x06UserId\x18\x03 \x01(\x03\x12\x11\n\tSessionId\x18\x04 \x01(\r2\x94\x01\n\x1a\x44igitalAssistantEntryPoint\x12v\n\x0fGetTextResponse\x12\x30.dig.ass.ep.v1.DigitalAssistantEntryPointRequest\x1a\x31.dig.ass.ep.v1.DigitalAssistantEntryPointResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dig_ass_ep_protos.DigitalAssistantEntryPoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIGITALASSISTANTENTRYPOINTRESPONSE']._serialized_start=69
  _globals['_DIGITALASSISTANTENTRYPOINTRESPONSE']._serialized_end=119
  _globals['_DIGITALASSISTANTENTRYPOINTREQUEST']._serialized_start=122
  _globals['_DIGITALASSISTANTENTRYPOINTREQUEST']._serialized_end=254
  _globals['_OUTERCONTEXTITEM']._serialized_start=256
  _globals['_OUTERCONTEXTITEM']._serialized_end=335
  _globals['_DIGITALASSISTANTENTRYPOINT']._serialized_start=338
  _globals['_DIGITALASSISTANTENTRYPOINT']._serialized_end=486
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DigitalAssistantEntryPointResponse(_message.Message):
    __slots__ = ("Text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    Text: str
    def __init__(self, Text: _Optional[str] = ...) -> None: ...

class DigitalAssistantEntryPointRequest(_message.Message):
    __slots__ = ("Text", "OuterContext", "Image", "PDF")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    OUTERCONTEXT_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    PDF_FIELD_NUMBER: _ClassVar[int]
    Text: str
    OuterContext: OuterContextItem
    Image: bytes
    PDF: bytes
    def __init__(self, Text: _Optional[str] = ..., OuterContext: _Optional[_Union[OuterContextItem, _Mapping]] = ..., Image: _Optional[bytes] = ..., PDF: _Optional[bytes] = ...) -> None: ...

class OuterContextItem(_message.Message):
    __slots__ = ("Sex", "Age", "UserId", "SessionId")
    SEX_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    USERID_FIELD_NUMBER: _ClassVar[int]
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    Sex: bool
    Age: int
    UserId: int
    SessionId: int
    def __init__(self, Sex: bool = ..., Age: _Optional[int] = ..., UserId: _Optional[int] = ..., SessionId: _Optional[int] = ...) -> None: ...
